﻿using System;
using System.Collections.Generic;

using Xamarin.Forms;

namespace Swiping
{
	public partial class MainPage : MasterDetailPage
	{

		Color origContentBgColor;
		Color origPageBgColor;

		public MainPage()
		{
			InitializeComponent();
			masterPage.ListView.ItemSelected += OnItemSelected;

			Detail = new NavigationPage(new SwipingPage())
			{
				BarBackgroundColor = Color.FromHex("#007AFF"),
				BarTextColor = Color.White
			};

			switch (Device.RuntimePlatform)
			{
				case Device.Windows:
					Master.Icon = "swap.png";
					break;
				default:
					break;
			}

		}

		async void Handle_IsPresentedChanged(object sender, System.EventArgs e)
		{
			switch (Device.RuntimePlatform)
			{
				case Device.iOS: //Dim the Detail page on iOS When Master Page is opened
					if (IsPresented)
					{
						var currentPage = (ContentPage)((NavigationPage)this.Detail).CurrentPage;
						origPageBgColor = currentPage.BackgroundColor;
						origContentBgColor = currentPage.Content.BackgroundColor;

						currentPage.BackgroundColor = Color.Black;
						if (currentPage.Content.BackgroundColor == Color.Default)
						{
							currentPage.Content.BackgroundColor = Color.White;
						}
						await currentPage.Content.FadeTo(0.5);
					}
					else
					{
						var currentPage = (ContentPage)((NavigationPage)this.Detail).CurrentPage;
						currentPage.BackgroundColor = origPageBgColor;
						currentPage.Content.BackgroundColor = origContentBgColor;
						await currentPage.Content.FadeTo(1.0);
					}
					break;
				default:
					break;
			}
		}

		void OnItemSelected(object sender, SelectedItemChangedEventArgs e)
		{
			var item = e.SelectedItem as MasterPageItem;
			if (item != null)
			{
				Detail = new NavigationPage((Page)Activator.CreateInstance(item.TargetType))
				{
					BarBackgroundColor = Color.FromHex("#007AFF"),
					BarTextColor = Color.White
				};
				masterPage.ListView.SelectedItem = null;
				IsPresented = false;
			}
		}
	}
}